// src/index.ts
import crypto, { pbkdf2 as deriveKey } from "crypto";
import { Chacha20 } from "ts-chacha20";
function pbkdf2({ password, salt }) {
  return new Promise((resolve, reject) => {
    deriveKey(password, salt, 1, 64, "sha256", (error, key) => {
      if (error)
        return reject(error);
      resolve(key);
    });
  });
}
function generateRandom(length = 16) {
  return Buffer.from(crypto.randomBytes(length));
}
async function aesEncrypt(data, password) {
  const salt = generateRandom(12);
  const key = await pbkdf2({ password, salt });
  const encrypt = new Chacha20(key.subarray(0, 32), salt).encrypt(Buffer.from(data));
  const packaged = Buffer.concat([salt, encrypt]);
  return packaged.toString("base64");
}
async function aesDecrypt(data, password) {
  const unpackaged = Buffer.from(data, "base64");
  const salt = unpackaged.subarray(0, 12);
  const input = unpackaged.subarray(12, data.length);
  const key = await pbkdf2({ password, salt });
  const message = new Chacha20(key.subarray(0, 32), salt).decrypt(input);
  return Buffer.from(message).toString("utf8");
}
export {
  aesDecrypt,
  aesEncrypt,
  pbkdf2
};
